var wxwidgets__dev_8cpp =
[
    [ "Scaler", "classScaler.html", "classScaler" ],
    [ "OriginChanger", "classOriginChanger.html", "classOriginChanger" ],
    [ "DrawingObjectsChanger", "classDrawingObjectsChanger.html", "classDrawingObjectsChanger" ],
    [ "TextObjectsSaver", "classTextObjectsSaver.html", "classTextObjectsSaver" ],
    [ "TextObjectsChanger", "classTextObjectsChanger.html", "classTextObjectsChanger" ],
    [ "Clipper", "classClipper.html", "classClipper" ],
    [ "Rand", "classRand.html", "classRand" ],
    [ "DEBUG", "wxwidgets__dev_8cpp.html#ad72dbcf6d0153db1b8d8a58001feed83", null ],
    [ "NEED_PLDEBUG", "wxwidgets__dev_8cpp.html#ad92ef941bb38ab1d2af3bce830fd47c9", null ],
    [ "getTextOffset", "wxwidgets__dev_8cpp.html#a94a325646f3a09b69897ed5d34b505ee", null ],
    [ "operator==", "wxwidgets__dev_8cpp.html#a1cc916f725de04817aeb2ae4aea4a14d", null ],
    [ "plFontToWxFontParameters", "wxwidgets__dev_8cpp.html#a1d06ba4e022ce42c3abd71fb5bfc774b", null ]
];